@@ -365,11 +365,46 @@ namespace gnote {
     return new_main_window();
   }
 
-  void Gnote::open_search_all()
+  MainWindow & Gnote::open_search_all()
   {
-    MainWindow & main_window = get_main_window();
-    main_window.present_search();
-    main_window.present();
+    // if active window is search, just show it
+    MainWindow *rc = get_active_window();
+    if(rc) {
+      if(rc->is_search()) {
+        return *rc;
+      }
+    }
+
+    // present already open search window, if there is one
+    std::vector<Gtk::Window*> windows = Gtk::Window::list_toplevels();
+    int main_windows = 0;
+    for(std::vector<Gtk::Window*>::iterator iter = windows.begin();
+        iter != windows.end(); ++iter) {
+      auto win = dynamic_cast<MainWindow*>(*iter);
+      if(win) {
+        ++main_windows;
+        if(win->is_search()) {
+          return *win;
+        }
+        else if(rc == NULL) {
+          rc = win;
+        }
+      }
+    }
+
+    // if notes are opened in new window by default, then open new window for search
+    // otherwise switch the only window to search
+    // if there is more than one window open, open new for search, since we can't decide which one to switch
+    bool new_window = Preferences::obj()
+      .get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW);
+    if(main_windows > 1 || new_window) {
+      MainWindow & main_window = new_main_window();
+      main_window.present_search();
+      return main_window;
+    }
+
+    rc->present_search();
+    return *rc;
   }
 
   void Gnote::open_note_sync_window(const Glib::VariantBase&)
