@@ -220,6 +220,8 @@ namespace gnote {
   {
     m_search_entry.set_activates_default(false);
     m_search_entry.set_size_request(300);
+    m_search_entry.signal_key_press_event()
+      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_entry_key_pressed), false);
     m_search_entry.signal_changed()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_entry_changed));
     m_search_entry.signal_activate()
@@ -382,6 +384,12 @@ namespace gnote {
   }
 
 
+  bool NoteRecentChanges::is_search()
+  {
+    return &m_search_notes_widget == currently_embedded();
+  }
+
+
   void NoteRecentChanges::on_close_window(const Glib::VariantBase&)
   {
     close_window();
@@ -515,7 +523,7 @@ namespace gnote {
       if(width && height) {
         set_default_size(width, height);
         if(!maximized && get_visible()) {
-          get_window()->resize(width, height);
+          resize(width, height);
         }
       }
       widget.size_internals();
@@ -626,6 +634,17 @@ namespace gnote {
     return res;
   }
 
+  bool NoteRecentChanges::on_entry_key_pressed(GdkEventKey *event)
+  {
+    switch(event->keyval) {
+    case GDK_KEY_Escape:
+      m_search_entry.set_text("");
+      m_search_button.set_active(false);
+    }
+
+    return false;
+  }
+
   void NoteRecentChanges::on_entry_changed()
   {
     if(!m_search_box.get_visible()) {
@@ -812,6 +831,7 @@ namespace gnote {
     switch(evt->keyval) {
     case GDK_KEY_Escape:
     case GDK_KEY_Delete:
+    case GDK_KEY_Tab:
       return false;
     case GDK_KEY_BackSpace:
       if(m_search_button.get_active()) {
